/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    REXX-Proc zur bernahme von PMDIARY-Adressdaten in das Telefonbuch      */
/*    von IBMWORKS (FPWPIM.EXE).                                              */
/*                                                                            */
/*    Da wahrscheinlich jeder PMDIARY-Benutzer seine eigenen Datenstruktur    */
/*    definiert hat, mu diese Prozedur zuerst an die eigenen Belange         */
/*    angepat werden.                                                        */
/*                                                                            */
/*    Zustzlich zu dieser REXX-Proc wird noch das Paket 'RXBAS134.ZIP'       */
/*    bentigt, das auf allen gut sortierten OS/2 Mailboxen erhltlich        */
/*    sein sollte.                                                            */
/*                                                                            */
/*    Kopieren Sie aus diesem Paket die Datei 'REXXBASE.DLL' in ein           */
/*    Verzeichnis im 'LIBPATH' oder in das aktuelle Arbeitsverzeichnis,       */
/*    sofern Sie die Angabe '.;' im 'LIBPATH' eingetragen haben.              */
/*                                                                            */
/*                                                                            */
/*    Vorgehensweise:                                                         */
/*                                                                            */
/*    1. REXX-Proc anpassen                                                   */
/*                                                                            */
/*    2. Die Dateien PHONE.* im \IBMWORKS\DATA Verzeichnis                    */
/*       vorsichtshalber sichern                                              */
/*                                                                            */
/*    3. Aufruf der Prozedur mit                                              */
/*          migrate <Pfad>\PMDIARY.$$F \IBMWORKS\DATA\PHONE.DBF               */
/*                                                                            */
/*    4. Telefonbuch starten und staunen ;-)                                  */
/*                                                                            */
/*                                                                            */
/*    Falls es Probleme geben sollte, bin ich unter den folgenden             */
/*    Adressen zu erreichen:                                                  */
/*                                                                            */
/*       Oliver Ludwig                                                        */
/*                                                                            */
/*       CIS:       100065,1743                                               */
/*       INTERNET:  devd9pz9@ibmmail.com                                      */
/*       FIDO:      2:246/1408                                                */
/*                                                                            */
/*       BBS:       07907-940025 (nur ISDN X.75)                              */
/*                                                                            */
/*----------------------------------------------------------------------------*/

signal on SYNTAX 
signal on HALT 

parse arg infile dbf


if dbf == "" then do
   say "syntax: migrate <Adressdatei> <Datenbank>"
   say
   say "z.B.    migrate e:\daten\pmd\adr.$$f e:\ibmworks\data\phone.dbf"  
   exit 12
end 


if stream( infile, "C", "QUERY EXISTS" ) == "" then do
   say "Die Eingabedatei '" || infile || "' ist nicht vorhanden !"
   exit 13
end 


ret = rxfuncadd(rexxbase_init,"REXXBASE",Rexxbase_Init);
ret = rexxbase_init()
ret = rexxbase_opendbf("dbf")


if ret <> "" then do
   say ""
   say "Fehler beim ffnen der Datenbank"
   say "Originalfehlermeldung:" ret
   exit 14
end  

rexxbase.formatdate = 'off'


/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Zuerst mu der max. Inhalt des Datenbankfeldes INDEX ermittelt werden   */
/*                                                                            */
/*----------------------------------------------------------------------------*/

i = 0
do x = 1 to  dbf.recordcount
   ret = rexxbase_readdbf("dbf")
   i = max( i, dbf.INDEX )
end 


/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Einlesen der PMDIARY-Adressdatei                                        */
/*                                                                            */
/*----------------------------------------------------------------------------*/

buffer = linein( infile )                       /* 1. Zeile ignorieren        */
do while lines( infile )
   i = i + 1
   buffer = linein( infile )                    /* Zeile einlesen             */

   /*-------------------------------------------------------------------------*/
   /* Hier mu nun jede Zeile der Eingabedatei auf einzelne Variablen         */
   /* aufgeteilt werden.                                                      */
   /*                                                                         */
   /* Das Beispiel bezieht sich auf einen Datensatz, der wie folgt aussieht:  */
   /*                                                                         */
   /*    Hacker, Hugo                                                         */
   /*    Testfirma                                                            */
   /*    Hauptstrae 57                                                       */
   /*    12345 Testhausen                                                     */
   /*    0123-45678                                                           */
   /*    0123-45679                                                           */
   /*    hacker@irgendwo.de                                                   */
   /*    01.01.1970                                                           */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   parse value buffer with,                     
      src.name "|",                             /*          <=====            */
      src.firma "|",                            /*          <=====            */
      src.strasse "|",                          /*          <=====            */
      src.ort "|",                              /*          <=====            */
      src.tel1 "|",                             /*          <=====            */
      src.tel2 "|",                             /*          <=====            */
      src.email "|",                            /*          <=====            */
      src.gebdatum "|",                         /*          <=====            */
      rest


   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Da das neue Telefonbuch getrennte Felder fr Vor- und Zuname hat,       */
   /* mu das ursprngliche Feld getrennt werden                              */
   /*                                                                         */
   /* Da bei mir zuerst der Zuname und dann der Vorname durch ein Komma       */
   /* getrennt abgespeichert war, mu hier das Komma gesucht und die          */
   /* Zeichenkette entsprechend geteilt werden.                               */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   p = pos( ",", src.name )                     /* Komma suchen               */

   if p > 0 then do
      src.vorname = strip( substr( src.name, p + 1 ) )
      src.name    = strip( left( src.name, p - 1 ) )
   end  
   else do                                      /* Keine Komma vorhanden      */
      src.vorname = ""
   end  


   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Und jetzt das gleiche Spiel mit PLZ und Ort                             */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   p = pos( " ", src.ort )                      /* Blank suchen               */
   if p > 0 then do
      src.plz     = strip( left( src.ort, p - 1 ) )
      src.ort     = strip( substr( src.ort, p + 1 ) )
   end  
   else do                                      /* Kein Blank vorhanden       */
      src.plz     = ""
   end  


   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Und jetzt mit der Telefon-Nr.                                           */
   /*                                                                         */
   /* In dem neuen Telefonbuch gibt es je Telefoneintrag 4 getrennte Eingabe- */
   /* felder fr Landesvorwahl, Vorwahl, Rufnummer und Durchwahl.             */
   /*                                                                         */
   /* Diese 4 Felder werden in der Datenbank jedoch in einem Feld gespeichert,*/
   /* wobei die einzelnen Teile durch einen '|' getrennt werden.              */
   /*                                                                         */
   /* Da ich die Landesvorwahl nicht nutze und mit die Darstellung der        */
   /* Durchwahl nicht gefllt, habe ich mich auf die Felder Vorwahl und       */
   /* Rufnummer beschrnkt.                                                   */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   p = pos( "-", src.tel1 )                     /* Bindestrich zw. Vorwahl    */
                                                /* und Rufnummer suchen       */
   if p > 0 then do
      src.vorw1   = strip( left( src.tel1, p - 1 ) )
      src.rufn1   = strip( substr( src.tel1, p + 1 ) )
   end  
   else do                                      /* Kein Bindestrich vorhanden */
      src.vorw1   = src.tel1
      src.rufn1   = ""
   end  


   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Das selbe nochmal fr die 2. Telefonnummer                              */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   p = pos( "-", src.tel2 )                     /* Bindestrich zw. Vorwahl    */
                                                /* und Rufnummer suchen       */
   if p > 0 then do
      src.vorw2   = strip( left( src.tel2, p - 1 ) )
      src.rufn2   = strip( substr( src.tel2, p + 1 ) )
   end  
   else do                                      /* Kein Bindestrich vorhanden */
      src.vorw2   = src.tel2
      src.rufn2   = ""
   end  


   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Falls Sie noch weitere Felder haben, die eine besondere Behandlung      */
   /* bentigen, dann knnen Sie das hier ergnzen                            */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/



   /*-------------------------------------------------------------------------*/
   /*                                                                         */
   /* Jetzt mssen die einzelnen Variablen noch der Datenbankstruktur         */
   /* zugewiesen werden                                                       */
   /*                                                                         */
   /*-------------------------------------------------------------------------*/

   /*-------------------------------------------------------------------------*/
   /* 1. Adresse                                                              */
   /*-------------------------------------------------------------------------*/

   dbf.SALUT      = ""
   dbf.LNAME      = src.name                    
   dbf.FNAME      = src.vorname                        
   dbf.TITLE      = ""                                 
   dbf.COMPANY    = src.firma
   dbf.COADDR1    = src.strasse
   dbf.COADDR2    = ""
   dbf.COCITY     = src.ort                            
   dbf.COSTATE    = ""
   dbf.COZIP      = src.plz     
   dbf.COCOUNTRY  = ""

   /*-------------------------------------------------------------------------*/
   /* 2. Adresse                                                              */
   /*-------------------------------------------------------------------------*/

   dbf.HOADDR1    = ""                          
   dbf.HOADDR2    = ""
   dbf.HOCITY     = ""
   dbf.HOSTATE    = ""
   dbf.HOZIP      = ""
   dbf.HOCOUNTRY  = ""

   /*-------------------------------------------------------------------------*/
   /* Telefonnummern                                                          */
   /*-------------------------------------------------------------------------*/

   dbf.LABEL1     = "Privat 1"
   dbf.NUMBER1    = "|"src.vorw1"|"src.rufn1"|"
   dbf.LABEL2     = "Privat 2"
   dbf.NUMBER2    = "|"src.vorw2"|"src.rufn2"|"
   dbf.LABEL3     = ""
   dbf.NUMBER3    = ""
   dbf.LABEL4     = ""
   dbf.NUMBER4    = ""
   dbf.LABEL5     = ""
   dbf.NUMBER5    = ""
   dbf.LABEL6     = ""
   dbf.NUMBER6    = ""
   dbf.LABEL7     = ""
   dbf.NUMBER7    = ""
   dbf.LABEL8     = ""
   dbf.NUMBER8    = ""

   dbf.ICON       = ""
   dbf.CONTACT    = "F"
   dbf.NOTES      = ""

   /*-------------------------------------------------------------------------*/
   /* 1. Seite der benutzerdefinierten Eintrge                               */
   /*-------------------------------------------------------------------------*/

   dbf.CUSTOM1    = src.gebdatum
   dbf.CUSTOM2    = ""
   dbf.CUSTOM3    = ""
   dbf.CUSTOM4    = ""
   dbf.CUSTOM5    = ""

   dbf.CHECK1     = "F"
   dbf.CHECK2     = "F"
   dbf.CHECK3     = "F"
   dbf.CHECK4     = "F"
   dbf.CHECK5     = "F"
   dbf.CHECK6     = "F"

   /*-------------------------------------------------------------------------*/
   /* 2. Seite der benutzerdefinierten Eintrge                               */
   /*-------------------------------------------------------------------------*/

   dbf.CUSTOM6    = src.email   
   dbf.CUSTOM7    = ""
   dbf.CUSTOM8    = ""
   dbf.CUSTOM9    = ""
   dbf.CUSTOM10   = ""

   dbf.CHECK7     = "F"
   dbf.CHECK8     = "F"
   dbf.CHECK9     = "F"
   dbf.CHECK10    = "F"
   dbf.CHECK11    = "F"
   dbf.CHECK12    = "F"

   /*-------------------------------------------------------------------------*/
   /* Verwaltungsinfo's bitte nicht ndern !!!                                */
   /*-------------------------------------------------------------------------*/

   dbf.LASTEDIT   = date(s) || time(h) || substr( time(), 4, 2 )
   dbf.FOLDER     = 0
   dbf.INDEX      = i


   ret = rexxbase_writedbf( "dbf" )
   call error ret ':rexxbase_writedbf()'

end /* do */


signal halt



/*---------------------------------------------------------------------------*/

halt:
   ret = rexxbase_closedbf( "dbf" )
   call error ret ':rexxbase_closedbf()'

   ret = rexxbase_shutdown()
   exit 0
return

syntax:
   errormsg = 'rexx error ' rc ' in line  ' sigl ':' errortext(rc)
   say errormsg
   say  sourceline(sigl)
   call done
exit


/*---------------------------------------------------------------------------*/

error: procedure 
   parse arg ret ':'text
   if ret \= '' then say 'RC =' ret '-' text
  
return
